"use strict";
/*
 * @microeinhundert/radonis-unocss
 *
 * (c) Leon Seipp <l.seipp@microeinhundert.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.unocssPlugin = void 0;
const promises_1 = require("node:fs/promises");
const radonis_1 = require("@microeinhundert/radonis");
const radonis_shared_1 = require("@microeinhundert/radonis-shared");
const node_1 = require("@microeinhundert/radonis-shared/node");
const core_1 = require("@unocss/core");
const config_1 = require("./config");
/**
 * Plugin for integrating {@link https://github.com/unocss/unocss UnoCSS} with Radonis
 * @see https://radonis.vercel.app/docs/plugins/unocss
 */
function unocssPlugin(config) {
    let cssInjected = false;
    let css;
    const tokens = new Set();
    return (0, radonis_1.definePlugin)({
        name: 'unocss',
        environments: ['server'],
        async onBootServer({ resourcesPath }) {
            const extensions = ['.ts', '.tsx', '.js', '.jsx', '.json', '.md', '.mdx'];
            const generator = (0, core_1.createGenerator)(config ?? config_1.config);
            const paths = await (0, node_1.fsReadAll)(resourcesPath, {
                filter: (path) => extensions.some((extension) => path.endsWith(extension)),
            });
            /**
             * Search for classes in files
             */
            for (const path of paths) {
                const contents = await (0, promises_1.readFile)(path, { encoding: 'utf-8' });
                await generator.applyExtractors(contents, path, tokens);
            }
            const generatorResult = await generator.generate(tokens, {
                minify: radonis_shared_1.isProduction,
            });
            css = generatorResult.css;
        },
        beforeRequest() {
            cssInjected = false;
        },
        afterRender() {
            return (html) => {
                const hasHead = html.includes('</head>');
                if (!cssInjected && css && hasHead) {
                    cssInjected = true;
                    return html.replace('</head>', `\n<style>${css}</style>\n</head>`);
                }
                return html;
            };
        },
    });
}
exports.unocssPlugin = unocssPlugin;
//# sourceMappingURL=plugin.js.map